dival.reconstructors.standard\_learned\_reconstructor module
============================================================

.. automodule:: dival.reconstructors.standard_learned_reconstructor
   :members:
   :undoc-members:
   :show-inheritance:
